@@ -1,5 +1,5 @@
-import { awscdk } from 'projen';
-const project = new awscdk.AwsCdkConstructLibrary({
+import * as projen from 'projen';
+const project = new projen.awscdk.AwsCdkConstructLibrary({
   name: 'pwed-cdk',
   description: 'A library of AWS CDK constructs that I have created',
   repositoryUrl: 'https://github.com/pwed/pwed-cdk.git',
@@ -7,18 +7,16 @@ const project = new awscdk.AwsCdkConstructLibrary({
   author: 'Fred Stoddart',
   authorAddress: 'pwed@users.noreply.github.com',
 
-  cdkVersion: '2.5.0',
+  cdkVersion: '2.39.0',
   defaultReleaseBranch: 'main',
   stability: 'experimental',
   keywords: ['cdk', 'aws'],
   license: 'MIT',
 
-  // deps: [],
-  bundledDeps: ['glob', 'cdk-ec2-key-pair'],
-  peerDeps: [], // * Runtime dependencies of this module. */
-  // description: undefined,  /* The description is just a string that helps people understand the purpose of the package. */
-  devDeps: ['cdk-iam-floyd@0.300.0'] /* Build dependencies for this module. */,
-  // packageName: undefined,  /* The "name" in package.json. */
+  deps: ['cdk-iam-floyd@0.300.0'],
+  bundledDeps: ['glob', 'cdk-ec2-key-pair', 'cdk-iam-floyd'],
+  peerDeps: [], // Runtime dependencies of this module.
+  devDeps: ['cdk-iam-floyd@0.300.0'],
 
   prettier: true,
   prettierOptions: {
@@ -33,12 +31,26 @@ const project = new awscdk.AwsCdkConstructLibrary({
     dirs: ['src'],
   },
 
+  depsUpgradeOptions: {
+    workflowOptions: {
+      schedule: projen.javascript.UpgradeDependenciesSchedule.MONTHLY,
+    },
+  },
+
   // Publishing
+  // releaseWorkflowSetupSteps: [
+  //   {
+  //     name: 'Install acl',
+  //     run: 'apt-get update && apt-get install -y acl',
+  //   },
+  // ],
   releaseToNpm: true,
   publishToPypi: {
     distName: 'pwed-cdk',
     module: 'pwed_cdk',
   },
+
+  devContainer: true,
   projenrcTs: true,
 });
 project.synth();
