@@ -10,8 +10,11 @@ import { pwed_static_site } from 'pwed-cdk';
 import * as path from 'path';
 
 const website = new pwed_static_site.StaticSite(this, 'PwedDotMe', {
-  domain: 'pwed.me',
-  path: path.join(__dirname, 'static'),
+  domain: 'pwed.me',                     // Required
+  path: path.join(__dirname, 'static'),  // Required - path to static files
+  alternativeDomains: ['blog.pwed.me'],  // Optional - Other names
+  hostedZone: zone,                      // Optional - will lookup using the domain if not provided
+  enablePrettyPaths: true,               // Optional - will look for index.html in urls ending with a '/' or with no file type
 });
 ```
 '''
@@ -82,7 +85,7 @@ class StaticSite(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="distribution")
     def distribution(self) -> aws_cdk.aws_cloudfront.IDistribution:
         '''
